#
# spec file for package libdazzle
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libdazzle
Version:        3.26.3
Release:        lp150.1.3
Summary:        Collection of fancy features for GLib and Gtk+
License:        GPL-3.0+ AND LGPL-2.1+
Group:          Development/Tools/Other
Url:            https://git.gnome.org/browse/libdazzle/
Source0:        http://download.gnome.org/sources/libdazzle/3.26/%{name}-%{version}.tar.xz
BuildRequires:  gtk-doc
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(vapigen)

%description
This library is a companion library to GObject and Gtk+.
It provides various features that we wish were in the underlying
library but cannot for various reasons. In most cases, they are
wildly out of scope for those libraries. In other cases, our design
isn't quite generic enough to work for everyone.

%package -n     libdazzle-1_0-0
Summary:        Collection of fancy features for GLib and Gtk+ -- Library file
Group:          System/Libraries

%description -n libdazzle-1_0-0
This library is a companion library to GObject and Gtk+.
It provides various features that we wish were in the underlying
library but cannot for various reasons. In most cases, they are
wildly out of scope for those libraries. In other cases, our design
isn't quite generic enough to work for everyone.

This package provides the library file for libdazzle.

%package -n     typelib-1_0-libdazzle-1_0
Summary:        Collection of fancy features for GLib and Gtk+ -- Introspection bindings
Group:          System/Libraries

%description -n typelib-1_0-libdazzle-1_0
This library is a companion library to GObject and Gtk+.
It provides various features that we wish were in the underlying
library but cannot for various reasons. In most cases, they are
wildly out of scope for those libraries. In other cases, our design
isn't quite generic enough to work for everyone..

This package provides the GObject Introspection bindings for libdazzle.

%package        devel
Summary:        Collection of fancy features for GLib and Gtk+ -- Development Files
Group:          Development/Tools/Other
Requires:       %{name} = %{version}
Requires:       typelib-1_0-libdazzle-1_0 = %{version}

%description    devel
This library is a companion library to GObject and Gtk+.
It provides various features that we wish were in the underlying
library but cannot for various reasons. In most cases, they are
wildly out of scope for those libraries. In other cases, our design
isn't quite generic enough to work for everyone. -- Development Files

%prep
%autosetup

%build
%{meson} \
	-Denable_tracing=false \
	-Denable_profiling=false \
	-Denable_rdtscp=false \
	-Denable_tools=true \
	-Dwith_introspection=true \
	-Dwith_vapi=true \
	-Denable_gtk_doc=true \
	-Denable_tests=false \
	%{nil}
%{meson_build}

%install
%{meson_install}

%post -n libdazzle-1_0-0 -p /sbin/ldconfig
%postun -n libdazzle-1_0-0 -p /sbin/ldconfig

%files
%{_bindir}/dazzle-list-counters

%files -n libdazzle-1_0-0
%doc COPYING
%{_libdir}/libdazzle-1.0.so.*

%files -n typelib-1_0-libdazzle-1_0
%{_libdir}/girepository-1.0/Dazzle-1.0.typelib

%files devel
%doc AUTHORS CONTRIBUTING.md NEWS README.md
%doc %{_datadir}/gtk-doc/html/libdazzle/
%{_includedir}/libdazzle-1.0/
%{_datadir}/gir-1.0/Dazzle-1.0.gir
%{_libdir}/libdazzle-1.0.so
%{_libdir}/pkgconfig/libdazzle-1.0.pc
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/libdazzle-1.0.deps
%{_datadir}/vala/vapi/libdazzle-1.0.vapi

%changelog
* Fri Feb  2 2018 bjorn.lie@gmail.com
- Update to vresion 3.26.3:
  + A number of fixes to DzlSignalGroup to be more re-entrant safe
    and handle disposal cycles better.
  + DzlPreferences is more aggressive about protecting against
    widget disposal.
  + A static inline dzl_clear_signal_handler() was backported for
    use in other backports from master.
  + A number of protections were added to DzlDirectoryReaper to
    protect against potentially following through symlinks.
  + Max age in DzlDirectoryReaper was changed to always ensure a
    positive value for use in date comparisons.
  + A leak of GFile instances in the directory reaper was fixed.
- Drop unused base define.
* Fri Jan 19 2018 bjorn.lie@gmail.com
- Update to version 3.26.2:
  + Progress menu button will now avoid spinning in some
    conditions.
  + Leak fixed in DzlTree text rendering.
  + Shortcut mneumonics are now properly activated.
  + Fixes to avoid various deprecated API.
  + A number of leaks detected by ASAN were fixed.
  + The directory reaper handles various mtime comparisons more
    correctly now.
  + Some G-I annotations were improved.
  + DzlMenuMerger is more flexible with input.
  + Some performance improvements when dealing with CSS and other
    resources paths.
* Thu Oct  5 2017 dimstar@opensuse.org
- Update to version 3.26.1:
  + icons: avoid thrashing the GtkIconTheme on startup.
  + prefs: track destruction state of pref widgets.
  + macros: add a few internally used macros to public API.
  + tests: crib some test data for portable tests.
  + file-chooser-entry: be lazy with dialog construction.
* Mon Sep 11 2017 zaitor@opensuse.org
- Update to version 3.26.0:
  + Fix tab/shift+tab to change focus when using shortcut manager.
  + Manually set marshaller and va marshallers on DzlTreeBuilder
    which helps slightly with performance of signal emission.
  + Various Mingw build fixes.
- Add gtk-doc BuildRequires, build documentation.
- Pass  enable_tracing=false, enable_profiling=false,
  enable_rdtscp=false, enable_tools=true, with_introspection=true,
  with_vapi=true, enable_gtk_doc=true and enable_tests=false to
  meson, ensure we build the features we want.
* Thu Sep  7 2017 dimstar@opensuse.org
- Update to version 3.25.92:
  + Enforce GNU11 C standard when configuring project.
  + DzlApplicationWindow automatically queries the shortcut
    manager.
  + The shortcut manager now checks GtkApplication registered
    accelerators providing an improved migration strategy for
    applications.
  + Lifecycle tests were removed from the test-fuzzy-index as they
    were racy via delayed disposal of threaded workers. This should
    fix unit tests for various distributions on less common
    hardware.
  + Menu buttons now remove the proper section item when handling
    GMenuModel changes.
  + Our meson-based build system now checks if version-script is
    supported and only applies the ABI map in that case. We may
    consider switching to export macros in the future.
  + Counters are now disabled on Windows.
  + Various compiler pre-processor checks have been improved.
  + A fallback for strcasecmp() is included for Windows.
  + DzlSuggestion will now use intern'd strings for icon-names to
    help reduce the number of duplicate strings in memory.
  + Various CSS styling refinements.
  + DzlListBox fixed a lingering pointer to the cached row during
    disposal.
* Fri Aug 25 2017 zaitor@opensuse.org
- Update to version 3.25.91:
  + DzlDirectoryReaper now properly removes recursive directories.
  + DzlListStoreAdapter is a new GListModel->GtkTreeModel adapter.
  + DzlSignalGroup had an overzealous assertion which was removed
    and corner case handled.
  + DzlShortcutTheme properly handles closure chain parse failure
    case.
  + DzlShortcutManager can handle DzlShortcutEntry that are not
    static allocations.
* Mon Aug 14 2017 zaitor@opensuse.org
- Update to version 3.25.90:
  + DzlSignalGroup and DzlBIndingGroup were made LGPLv2.1+ so they
    can be copied into projects that cannot link against libdazzle.
  + DzlDockBin got a number of bug fixes.
  + Various compilation fixes for less used compilers.
  + DzlTree gained support for "expanded icon names".
  + DzlTree has a new "always-expand" property to ensure it stays
    expanded.
  + DzlDockStack no longer requires homogeneous sized children.
  + DzlStackList transition animations have been tweaked to more
    closely reflect physical locality.
  + Calculated animation duration was sped up 1.5x.
* Sat Jul 22 2017 zaitor@opensuse.org
- Initial packaging for openSUSE, version 3.25.5.
